@@ -10,10 +10,11 @@ use metaclass (
 use Moose;
 use Params::Util qw( _STRING _IDENTIFIER );
 use WiX3::Types qw( YesNoType ComponentGuidType );
-use MooseX::Types::Moose qw( Str Maybe Int );
+use WiX3::XML::TagTypes qw( ComponentChildTag );
+use MooseX::Types::Moose qw( Str Maybe Int ArrayRef Undef );
 use WiX3::Util::StrictConstructor;
 
-our $VERSION = '0.009100';
+our $VERSION = '0.010002';
 $VERSION =~ s/_//ms;
 
 # http://wix.sourceforge.net/manual-wix3/wix_xsd_component.htm
@@ -23,6 +24,11 @@ with qw(WiX3::XML::Role::TagAllowsChildTags
   WiX3::Role::Traceable
 );
 
+## Environment, File, RegistryKey, RegistryValue, RemoveFolder, Shortcut
+## are ComponentChildTags at the moment.
+
+has '+child_tags' => ( isa => ArrayRef [ComponentChildTag] );
+
 ## Allows lots of children: Choice of elements AppId, Category, Class,
 ## Condition, CopyFile, CreateFolder, Environment, Extension, File, IniFile,
 ## Interface, IsolateComponent, ODBCDataSource, ODBCDriver, ODBCTranslator,
@@ -33,7 +39,6 @@ with qw(WiX3::XML::Role::TagAllowsChildTags
 
 #####################################################################
 # Accessors:
-#   None.
 
 has id => (
 	is      => 'ro',
@@ -61,9 +66,10 @@ has directory => (
 
 has disableregistryreflection => (
 	is      => 'ro',
-	isa     => Maybe [YesNoType],
+	isa     => YesNoType | Undef,
 	reader  => '_get_disableregistryreflection',
 	default => undef,
+	coerce  => 1,
 );
 
 has diskid => (
@@ -91,9 +97,10 @@ has guid => (
 
 has keypath => (
 	is      => 'ro',
-	isa     => Maybe [YesNoType],
+	isa     => YesNoType | Undef,
 	reader  => '_get_keypath',
 	default => undef,
+	coerce  => 1,
 );
 
 has location => (
@@ -105,9 +112,10 @@ has location => (
 
 has neveroverwrite => (
 	is      => 'ro',
-	isa     => Maybe [YesNoType],
+	isa     => YesNoType | Undef,
 	reader  => '_get_neveroverwrite',
 	default => undef,
+	coerce  => 1,
 );
 
 has path => (
@@ -119,48 +127,54 @@ has path => (
 
 has permanent => (
 	is      => 'ro',
-	isa     => Maybe [YesNoType],
+	isa     => YesNoType | Undef,
 	reader  => '_get_permanent',
 	default => undef,
+	coerce  => 1,
 );
 
 # Shared requires Windows Installer 4.5
 
 has shared => (
 	is      => 'ro',
-	isa     => Maybe [YesNoType],
+	isa     => YesNoType | Undef,
 	reader  => '_get_shared',
 	default => undef,
+	coerce  => 1,
 );
 
 has shareddllrefcount => (
 	is      => 'ro',
-	isa     => Maybe [YesNoType],
+	isa     => YesNoType | Undef,
 	reader  => '_get_shareddllrefcount',
 	default => undef,
+	coerce  => 1,
 );
 
 has transitive => (
 	is      => 'ro',
-	isa     => Maybe [YesNoType],
+	isa     => YesNoType | Undef,
 	reader  => '_get_transitive',
 	default => undef,
+	coerce  => 1,
 );
 
 # UninstallWhenSuperceded requires Windows Installer 4.5
 
 has uninstallwhensuperceded => (
 	is      => 'ro',
-	isa     => Maybe [YesNoType],
+	isa     => YesNoType | Undef,
 	reader  => '_get_uninstallwhensuperceded',
 	default => undef,
+	coerce  => 1,
 );
 
 has win64 => (
 	is      => 'ro',
-	isa     => Maybe [YesNoType],
+	isa     => YesNoType | Undef,
 	reader  => '_get_win64',
 	default => undef,
+	coerce  => 1,
 );
 
 #####################################################################
