@@ -1,10 +1,11 @@
 package WiX3::XML::Fragment::CreateFolder;
 
-use 5.008003;
-use Moose 2;
+use 5.008001;
+use Moose;
 use Params::Util qw( _IDENTIFIER );
 
-our $VERSION = '0.011';
+our $VERSION = '0.009100';
+$VERSION =~ s/_//ms;
 
 with 'WiX3::XML::Role::Fragment';
 
@@ -32,7 +33,7 @@ sub BUILDARGS {
 		my %args = %{ $_[0] };
 		$id           = $args{'id'};
 		$directory_id = $args{'directory_id'};
-	} elsif ( @_ == ( 2 * 2 ) ) {      # 2 pairs.
+	} elsif ( @_ == 4 ) {
 		my %args = {@_};
 		$id           = $args{'id'};
 		$directory_id = $args{'directory_id'};
