@@ -1,7 +1,7 @@
 package                                # Hide from PAUSE
   WiX3::XML::GeneratesGUID::Object;
 
-use 5.008003;
+use 5.008001;
 
 #use metaclass (
 #	base_class  => 'MooseX::Singleton::Object',
@@ -13,7 +13,8 @@ use Data::UUID qw( NameSpace_DNS );
 use WiX3::Types qw( Host );
 require WiX3::Exceptions;
 
-our $VERSION = '0.011';
+our $VERSION = '0.009100';
+$VERSION =~ s/_//ms;
 
 
 #####################################################################
@@ -53,10 +54,8 @@ has _sitename_guid => (
 		  $guidgen->create_from_name( Data::UUID::NameSpace_DNS,
 			$self->_get_sitename() );
 
-		$self->trace_line(
-			5, ## no critic(ProhibitMagicNumbers)
-			'Generated site GUID: ' . $guidgen->to_string($guid) . "\n"
-		);
+		$self->trace_line( 5,
+			'Generated site GUID: ' . $guidgen->to_string($guid) . "\n" );
 
 		return $guid;
 	},
